@@ -20,7 +20,7 @@ __metaclass__ = type
 import datetime
 import json
 import time
-import os.path
+import os
 
 from functools import partial
 
@@ -75,7 +75,8 @@ class CallbackModule(CallbackBase):
                 'host': play.get_name(),
                 'validation_id': self.env['playbook_name'],
                 'validation_path': self.env['playbook_path'],
-                'id': str(play._uuid),
+                'id': (os.getenv('ANSIBLE_UUID') if os.getenv('ANSIBLE_UUID')
+                       else str(play._uuid)),
                 'duration': {
                     'start': current_time()
                 }
@@ -147,7 +148,8 @@ class CallbackModule(CallbackBase):
 
         log_file = "{}/{}_{}_{}.json".format(
             VALIDATIONS_LOG_DIR,
-            self.results[0].get('play').get('id'),
+            (os.getenv('ANSIBLE_UUID') if os.getenv('ANSIBLE_UUID') else
+             self.results[0].get('play').get('id')),
             self.env['playbook_name'],
             self.current_time)
 
